svn commit: branches/uClibc-nptl/extra: Configs config locale scripts

sjhill at uclibc.org sjhill at uclibc.org
Sat Nov 19 22:09:31 UTC 2005


Author: sjhill
Date: 2005-11-19 14:09:29 -0800 (Sat, 19 Nov 2005)
New Revision: 12432

Log:
First batch of merges for new build system.


Modified:
   branches/uClibc-nptl/extra/Configs/Config.in
   branches/uClibc-nptl/extra/Configs/Config.in.arch
   branches/uClibc-nptl/extra/Configs/Config.mips
   branches/uClibc-nptl/extra/Makefile
   branches/uClibc-nptl/extra/config/Makefile
   branches/uClibc-nptl/extra/locale/Makefile
   branches/uClibc-nptl/extra/scripts/fix_includes.sh
   branches/uClibc-nptl/extra/scripts/gen_bits_syscall_h.sh
   branches/uClibc-nptl/extra/scripts/getent


Changeset:
Modified: branches/uClibc-nptl/extra/Configs/Config.in
===================================================================
--- branches/uClibc-nptl/extra/Configs/Config.in	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/Configs/Config.in	2005-11-19 22:09:29 UTC (rev 12432)
@@ -2,6 +2,7 @@
 # For a description of the syntax of this configuration file,
 # see extra/config/Kconfig-language.txt
 #
+
 mainmenu "uClibc C Library Configuration"
 
 choice
@@ -17,40 +18,43 @@
 	bool "arm"
 
 config TARGET_bfin
-	bool "bfin"
+	bool "bfin (BROKEN)"
 
 config TARGET_cris
-	bool "cris"
+	bool "cris (BROKEN)"
 
 config TARGET_e1
-	bool "e1"
+	bool "e1 (BROKEN)"
 
 config TARGET_frv
-	bool "frv"
+	bool "frv (BROKEN)"
 
 config TARGET_h8300
-	bool "h8300"
+	bool "h8300 (BROKEN)"
 
+config TARGET_hppa
+	bool "hppa"
+
 config TARGET_i386
 	bool "i386"
 
 config TARGET_i960
-	bool "i960"
+	bool "i960 (BROKEN)"
 
 config TARGET_m68k
 	bool "m68k"
 
 config TARGET_microblaze
-	bool "microblaze"
+	bool "microblaze (BROKEN)"
 
 config TARGET_mips
 	bool "mips"
 
 config TARGET_nios
-	bool "nios"
+	bool "nios (BROKEN)"
 
 config TARGET_nios2
-	bool "nios2"
+	bool "nios2 (BROKEN)"
 
 config TARGET_powerpc
 	bool "powerpc"
@@ -65,7 +69,7 @@
 	bool "sparc"
 
 config TARGET_v850
-	bool "v850"
+	bool "v850 (BROKEN)"
 
 config TARGET_x86_64
 	bool "x86_64"
@@ -103,6 +107,10 @@
 source "extra/Configs/Config.h8300"
 endif
 
+if TARGET_hppa
+source "extra/Configs/Config.hppa"
+endif
+
 if TARGET_i386
 source "extra/Configs/Config.i386"
 endif
@@ -167,18 +175,22 @@
 	default n
 
 config DOPIC
-	bool "Generate Position Independent Code (PIC)"
+	bool "Generate only Position Independent Code (PIC)"
 	default y
 	depends !HAVE_NO_PIC
 	help
-	  If you wish to build uClibc with support for shared libraries then
-	  answer Y here.  If you only want to build uClibc as a static library,
-	  then answer N.
+	  If you wish to build all of uClibc as PIC objects, then answer Y here.
+	  If you are unsure, then you should answer N.
 
 config HAVE_NO_SHARED
 	bool
 	default n
 
+config ARCH_HAS_NO_LDSO
+	bool
+	select HAVE_NO_SHARED
+	default n
+
 config HAVE_SHARED
 	bool "Enable support for shared libraries"
 	depends on !HAVE_NO_SHARED
@@ -188,11 +200,6 @@
 	  answer Y here.  If you only want to build uClibc as a static library,
 	  then answer N.
 
-config ARCH_HAS_NO_LDSO
-	bool
-	select HAVE_NO_SHARED
-	default n
-
 config FORCE_SHAREABLE_TEXT_SEGMENTS
 	bool "Only load shared libraries which can share their text segment"
 	depends on HAVE_SHARED
@@ -340,6 +347,20 @@
 	  If you are doing development and want to debug applications using
 	  uClibc's pthread library, answer Y.  Otherwise, answer N.
 
+config LINUXTHREADS_OLD
+	bool "Use the older (stable) version of linuxthreads"
+	default y
+	depends on UCLIBC_HAS_THREADS && !UCLIBC_HAS_THREADS_NATIVE
+	help
+	  There are two versions of linuxthreads.  The older (stable) version
+	  has been in uClibc for quite a long time but hasn't seen too many
+	  updates other than bugfixes.
+
+	  The new version has not been tested much, and lacks ports for arches
+	  which glibc does not support (like bfin/frv/etc...), but is based on
+	  the latest code from glibc, so it may be the only choice for the
+	  newer ports (like alpha/amd64/64bit arches and hppa).
+
 config UCLIBC_HAS_LFS
 	bool "Large File Support"
 	default y
@@ -764,8 +785,8 @@
 
 	  NOTE: This implementation limits the number or registered specifiers to 10.
 	  NOTE: This implementation requires new conversion specifiers to be ASCII
-                characters (0-0x7f).  This is to avoid problems with processing
-                format strings in locales with different multibyte conversions.
+	        characters (0-0x7f).  This is to avoid problems with processing
+	        format strings in locales with different multibyte conversions.
 
 	  Most people will answer N.
 
@@ -1146,15 +1167,10 @@
 endmenu
 
 
-menu "uClibc security related options"
+menu "Security options"
 
-config UCLIBC_SECURITY
-	bool "Enable security options"
-	default n
-
 config UCLIBC_BUILD_PIE
 	bool "Build utilities as ET_DYN/PIE executables"
-	depends on UCLIBC_SECURITY
 	depends on HAVE_SHARED
 	depends on TARGET_arm || TARGET_frv || TARGET_i386 || TARGET_mips || TARGET_powerpc
 	select FORCE_SHAREABLE_TEXT_SEGMENTS
@@ -1167,9 +1183,13 @@
 		libraries have to be built with -fPIC or -fpic, and all assembler
 		functions must be written as position independent code (PIC).
 
+config HAVE_NO_SSP
+	bool
+	default n
+
 config UCLIBC_HAS_SSP
 	bool "Support for propolice smashing stack protector"
-	depends on UCLIBC_SECURITY
+	depends on !HAVE_NO_SSP
 	default n
 	help
 	  Add propolice smashing stack protector to the library.
@@ -1224,7 +1244,6 @@
 
 config UCLIBC_BUILD_RELRO
 	bool "Build uClibc with RELRO"
-	depends on UCLIBC_SECURITY
 	depends on HAVE_SHARED
 	default y
 	help
@@ -1232,7 +1251,6 @@
 
 config UCLIBC_BUILD_NOW
 	bool "Build uClibc with NOW"
-	depends on UCLIBC_SECURITY
 	depends on HAVE_SHARED
 	default y
 	help
@@ -1240,7 +1258,6 @@
 
 config UCLIBC_BUILD_NOEXECSTACK
 	bool "Build uClibc with noexecstack marking"
-	depends on UCLIBC_SECURITY
 	default y
 	help
 	  Mark all assembler files as noexecstack. This will result in marking

Modified: branches/uClibc-nptl/extra/Configs/Config.in.arch
===================================================================
--- branches/uClibc-nptl/extra/Configs/Config.in.arch	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/Configs/Config.in.arch	2005-11-19 22:09:29 UTC (rev 12432)
@@ -20,7 +20,8 @@
 endchoice
 
 config ARCH_HAS_NO_MMU
-	bool
+	bool "Target CPU does not have a memory management unit (MMU)"
+	select ARCH_HAS_NO_LDSO if !TARGET_frv
 	default n
 
 config ARCH_HAS_MMU
@@ -110,4 +111,3 @@
 config HAVE_DOT_CONFIG
 	bool
 	default y
-

Modified: branches/uClibc-nptl/extra/Configs/Config.mips
===================================================================
--- branches/uClibc-nptl/extra/Configs/Config.mips	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/Configs/Config.mips	2005-11-19 22:09:29 UTC (rev 12432)
@@ -14,9 +14,6 @@
 	string
 	default "-mno-split-addresses"
 
-config ARCH_LDFLAGS
-	string
-
 config LIBGCC_CFLAGS
 	string
 

Modified: branches/uClibc-nptl/extra/Makefile
===================================================================
--- branches/uClibc-nptl/extra/Makefile	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/Makefile	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,28 +1,13 @@
 # Makefile for uClibc
 #
 # Copyright (C) 2000 by Lineo, inc.
-# Copyright (C) 2000,2001 Erik Andersen <andersen at uclibc.org>
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
 #
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU Library General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) any
-# later version.
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
 #
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU Library General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Library General Public License
-# along with this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-#
-# Derived in part from the Linux-8086 C library, the GNU C Library, and several
-# other sundry sources.  Files within this library are copyright by their
-# respective copyright holders.
 
-TOPDIR=../
-include $(TOPDIR)Rules.mak
+top_builddir=../
+include $(top_builddir)Rules.mak
 
 DIRS = 
 EXTRA_DIRS_TO_CLEAN = config

Modified: branches/uClibc-nptl/extra/config/Makefile
===================================================================
--- branches/uClibc-nptl/extra/config/Makefile	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/config/Makefile	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,23 +1,12 @@
 # Makefile for uClibc
 #
-# Copyright (C) 2002 Erik Andersen <andersen at codepoet.org>
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
 #
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU Library General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option) any
-# later version.
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
 #
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU Library General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Library General Public License
-# along with this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-TOPDIR=../../
-include $(TOPDIR)Rules.mak
+top_builddir=../../
+include $(top_builddir)Rules.mak
 
 all: ncurses conf mconf
 

Modified: branches/uClibc-nptl/extra/locale/Makefile
===================================================================
--- branches/uClibc-nptl/extra/locale/Makefile	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/locale/Makefile	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,11 +1,18 @@
+# Makefile for uClibc
+#
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
+#
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
+#
 
-TOPDIR = ../../
-EXTRA_LOCALE_DIR:=${shell cd $(TOPDIR)/extra/locale && pwd}
-include $(TOPDIR)Rules.mak
+top_builddir=../../
+include $(top_builddir)Rules.mak
 
+EXTRA_LOCALE_DIR:=${shell cd $(top_builddir)extra/locale && pwd}
+
 CFLAGS_wc8bit=-DCTYPE_PACKED=1
 CFLAGS_mmap=
-ifeq ($(strip $(UCLIBC_HAS_WCHAR)),y)
+ifeq ($(UCLIBC_HAS_WCHAR),y)
     CFLAGS_wc8bit += -DDO_WIDE_CHAR=1
     CFLAGS_mmap += -D__WCHAR_ENABLED=1
 endif

Modified: branches/uClibc-nptl/extra/scripts/fix_includes.sh
===================================================================
--- branches/uClibc-nptl/extra/scripts/fix_includes.sh	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/scripts/fix_includes.sh	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,21 +1,9 @@
 #!/bin/sh
-# Copyright (C) 2003 Erik Andersen <andersen at uclibc.org>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
-# License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later
-# version.
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Library General Public License for more details.
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
 #
-# You should have received a copy of the GNU Library General
-# Public License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
-# Boston, MA 02111-1307 USA
 
 usage () {
     echo ""

Modified: branches/uClibc-nptl/extra/scripts/gen_bits_syscall_h.sh
===================================================================
--- branches/uClibc-nptl/extra/scripts/getent	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/scripts/getent	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,4 +1,10 @@
 #!/bin/sh
+#
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
+#
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
+#
+
 # Script to replicate the `getent` binary that comes with glibc
 
 search_entry() {




More information about the uClibc-cvs mailing list
--- branches/uClibc-nptl/extra/scripts/gen_bits_syscall_h.sh	2005-11-19 21:04:15 UTC (rev 12431)
+++ branches/uClibc-nptl/extra/scripts/gen_bits_syscall_h.sh	2005-11-19 22:09:29 UTC (rev 12432)
@@ -1,15 +1,21 @@
 #!/bin/sh
 #
+# Copyright (C) 2001 Manuel Novoa III <mjn3 at uclibc.org>
+# Copyright (C) 2000-2005 Erik Andersen <andersen at uclibc.org>
+#
+# Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
+#
+
 # June 27, 2001         Manuel Novoa III
 #
 # This script expects TOPDIR and CC (as used in the Makefiles) to be set in
 # the environment, and outputs the appropriate $TOPDIR/include/bits/sysnum.h
 # corresponding to $TOPDIR/include/asm/unistd.h to stdout.
 #
 # Warning!!! This does _no_ error checking!!!
 
-UNISTD_H_PATH=$TOPDIR/include/asm/unistd.h
-INCLUDE_OPTS="-I$TOPDIR/include"
+UNISTD_H_PATH=$top_builddir/include/asm/unistd.h
+INCLUDE_OPTS="-I$top_builddir/include"
 
 ( echo "#include \"$UNISTD_H_PATH\"" ;
   $CC -E -dN $INCLUDE_OPTS $UNISTD_H_PATH | # needed to strip out any kernel-internal defines
@@ -1,15 +1,21 @@
 # June 27, 2001         Manuel Novoa III
 #
-# This script expects TOPDIR and CC (as used in the Makefiles) to be set in
-# the environment, and outputs the appropriate $TOPDIR/include/bits/sysnum.h
-# corresponding to $TOPDIR/include/asm/unistd.h to stdout.
+# This script expects top_builddir and CC (as used in the Makefiles) to be set in
+# the environment, and outputs the appropriate $top_builddir/include/bits/sysnum.h
+# corresponding to $top_builddir/include/asm/unistd.h to stdout.
 #
 # Warning!!! This does _no_ error checking!!!

Modified: branches/uClibc-nptl/extra/scripts/getent
===================================================================